;
;	Y by jimi
;	74 bytes on calc
;
;copies the graph screen to the current screen reflected over the
; Y axis and then exits
;can be used from ti-basic once image is loaded onto the graph screen
;will copy the axis if they are currently displayed (see below for
; information on how to turn off axis at start of routine)
;
_plotSScreen		=$c9fa		;1024 byte area for graph
					; screen image
_asm_exec_ram		=$d748		;start address of assembly
					; programs
;
.org _asm_exec_ram
;
;					;if you want to get rid of
;					; the axis (if they are
;					; turned on) then use
;					; two lines to set the
;					; appropriate flags
;					;usually people will have
;					; already turned
;	set grfnoaxis, (iy+grfdbflags)	;get rid of the axis
;	set graphdraw, (iy+graphflags)	;to finally get rid of
;					; axis have to tell it to
;					; regraph all functions
;
	ld hl,_plotSScreen
	ld de,$fc00
		push de			;save the start of the
					; video memory
	ld bc,1024
	ldir
		pop hl			;get back the start of the
					; video memory
;===============================================================
;  mirror over y-axis
;	input:	hl = to start of data to mirror (for graph screen
;		 it's "ld de,_plotSScreen")
;	output:	image reflected over y-axis
;		a = unpredictable (reverse of whatever was in
;		 last byte of image)
;		bc = $0000
;		de = $fff7
;		hl = $0000
;===============================================================
mirror_y_axis:
	ld b,64			;64 rows of pixels
mirror_y_axis_row_loop:
		push bc		;save our main row byte counter
				;get de to point to end of row
		push hl		;temporarily save beginning of
				; row so we can find end of
				; current row
	ld de,16-1		;16 bytes to be on next row down,
				; we want end of current so we
				; do 15 bytes
	add hl,de
	ex de,hl		;de is now at the end of the
				; current row
		pop hl		;get back address of start of row
;
flip_row:
	ld b,8			;8 bytes on each side of screen
				; (when divided down middle)
flip_row_loop:
		push bc		;save our row byte counter
flip_byte_left:
	ld a,(hl)		; a = (hl) 	left side
	ld b,8			;8 bits to rotate
flip_byte_left_loop:
	rla			;rotate left side's byte to left
				; putting bit rotated out into
				; the carry
	rr (hl)			;rotate carry (set/res) right
				; into the right side
	djnz flip_byte_left_loop
flip_byte_right:
		push hl
	ld h,d			;we can't us 'rl (de)' so we
				; need to make de temporarily hl
	ld l,e			; and still retain de's address
;
	ld a,(hl)		;a = (hl) =(de) what was on
				; right side
;
	ld b,8			;8 bits in byte to rotate
flip_byte_right_loop:
	rra			;rotate left side's byte to left
				; putting bit rotated out into
				; the carry
	rl (hl)			;rotate carry (set/res) right
				; into the right side
	djnz flip_byte_right_loop
		pop hl		;get back left side
	ld c,(hl)		;get left side out of the way
				; for now by saving it temporarily
	ld a,(de)		;save right side ready
	ld (hl),a		;put right side onto left side
	ld a,c			;get back our saved left side
	ld (de),a		;put it onto our right side
		pop bc		;get back our row byte counter
	inc hl			;move left side in one byte
	dec de			;move right side in one byte
	djnz flip_row_loop
;
	ld b,8			;currently it is in middle of
				; row so we put it at the end
				;we only need to put 8 into b
				; because c is zeroed at this
				; point
				;if you look above you see that
				; bc at the start was zeroed
				; by ldir, then we
				; pushed/poped so it is still 0
				;if we had done 'ld bc,8', that
				; would have been 3 bytes but
				; since c is already zeroed
				; all we have to do is load b
				; with 8
	add hl,bc		;move the last 8 bytes to get
				; the start of the row below
				; current one
		pop bc		;get back our main row counter 
	djnz mirror_y_axis_row_loop
	ret
;
.end
;